@@ -94,15 +94,20 @@ function playerGone(playerId) {
                 return;
             }
 
-            chrome.browserAction.setBadgeText({
-                text: null, // null resets tab-specific badge
+            chrome.action.setBadgeText({
+                text: "",
                 tabId: gonePlayerTabId // important to pass it as number!
             });
-            // Important to clear the color, too, so it reverts back to global badge setting
-            chrome.browserAction.setBadgeBackgroundColor({
-                color: null,
-                tabId: gonePlayerTabId
-            });
+
+            try {
+                // Important to clear the color, too, so it reverts back to global badge setting
+                chrome.action.setBadgeBackgroundColor({
+                    color: null,
+                    tabId: gonePlayerTabId
+                });
+            } catch (e) {
+                // Silence warning about missing 'text' and 'color' in Chrome
+            }
         });
     }
 
@@ -140,14 +145,23 @@ chrome.tabs.onUpdated.addListener((tabId, changes) => {
     }
 
     // Now check if the tab is actually gone
-    chrome.tabs.executeScript(tabId, {
-        code: `true`
-    }, (response) => {
+    chrome.scripting.executeScript({
+        target: {
+            tabId: tabId
+        },
+        func: () => {
+            return true;
+        }
+    }, (result) => {
         const error = chrome.runtime.lastError;
-        // Chrome error in script_executor.cc "kRendererDestroyed"
-        if (error && error.message === "The tab was closed.") {
-            console.warn("Player tab", tabId, "became inaudible and was considered crashed, signalling player gone");
-            playerTabGone(tabId);
+        if (error) {
+            // Chrome error in script_executor.cc "kRendererDestroyed"
+            if (error.message === "The tab was closed."
+                // chrome.scripting API with Manifest v3 gives this non-descript error.
+                || error.message === "Cannot access contents of the page. Extension manifest must request permission to access the respective host.") {
+                console.warn("Player tab", tabId, "became inaudible and was considered crashed, signalling player gone");
+                playerTabGone(tabId);
+            }
         }
     });
 });
@@ -221,11 +235,11 @@ addRuntimeCallback("mpris", "playing", function (message, sender) {
     sendPortMessage("mpris", "playing", payload);
 
     // Add toolbar icon to make it obvious you now have controls to disable the player
-    chrome.browserAction.setBadgeText({
+    chrome.action.setBadgeText({
         text: "♪",
         tabId: sender.tab.id
     });
-    chrome.browserAction.setBadgeBackgroundColor({
+    chrome.action.setBadgeBackgroundColor({
         color: "#1d99f3", // Breeze "highlight" color
         tabId: sender.tab.id
     });
